import pygame 
from pygame.locals import *

from Classes.Objects.Cards.MonsterCard import MonsterCard
from Classes.System.Window import Window
from Classes.System.InputHandler import InputHandler
from Classes.System.World import World


class App:

    __window:Window
    __running:bool = True
    __FPS = 60
    __clock = pygame.time.Clock()

    def __init__(self, width:int=1280, height:int=720, title:str="default title"):
        self.__window = Window(width=width, height=height, title=title)
        self.startGameLoop()
        self.onCleanup()
        
    def startGameLoop(self):

        # create sprite groups
        cards = pygame.sprite.Group()

        # game word
        world = World(pygame.image.load("Assets/Arenas/default.png").convert_alpha())

        testMonsterCard = MonsterCard((500,500), "Assets/Cards/MonsterCards/testmonstercard/")
        cards.add(testMonsterCard)

        while self.__running:

            self.__clock.tick(self.__FPS)

            self.__window.getScreen().fill("grey100")
            world.draw(self.__window.getScreen())

            # update sprite groups
            cards.update()

            # draw groups
            self.__window.drawSpriteGroup(cards)

            # event handler
            self.handleEvent(pygame.event.get())

            # emits update to the game
            pygame.display.update()

    # handles incoming event queue
    def handleEvent(self, events):
        for event in events:
            if event.type == pygame.QUIT:
                self.onCleanup()

    # sets the running state for the gameloop
    def setRunning(self, running:bool):
        self.__running = running

    # ensures the gameloop stops running and the pygame instance is stopped properly
    def onCleanup(self):
        self.__running = False
        pygame.quit()